@@ -19,8 +19,8 @@ using namespace Akregator;
 
 bool AkregatorConfigHandler::handleClick(const QUrl &url, ArticleViewerWebEngine *article) const
 {
-    if (url.scheme() == QLatin1String("config")) {
-        if (url.path() == QLatin1String("/disable_introduction")) {
+    if (url.scheme() == QLatin1StringView("config")) {
+        if (url.path() == QLatin1StringView("/disable_introduction")) {
             article->disableIntroduction();
             return true;
         }
@@ -30,13 +30,13 @@ bool AkregatorConfigHandler::handleClick(const QUrl &url, ArticleViewerWebEngine
 
 bool AkregatorConfigHandler::handleContextMenuRequest(const QUrl &url, const QPoint &, ArticleViewerWebEngine *) const
 {
-    return url.scheme() == QLatin1String("config");
+    return url.scheme() == QLatin1StringView("config");
 }
 
 QString AkregatorConfigHandler::statusBarMessage(const QUrl &url, ArticleViewerWebEngine *) const
 {
-    if (url.scheme() == QLatin1String("config")) {
-        if (url.path() == QLatin1String("/disable_introduction")) {
+    if (url.scheme() == QLatin1StringView("config")) {
+        if (url.path() == QLatin1StringView("/disable_introduction")) {
             return i18n("Disable Introduction");
         }
     }
@@ -45,7 +45,7 @@ QString AkregatorConfigHandler::statusBarMessage(const QUrl &url, ArticleViewerW
 
 QString MailToURLHandlerWebEngine::statusBarMessage(const QUrl &url, ArticleViewerWebEngine *) const
 {
-    if (url.scheme() == QLatin1String("mailto")) {
+    if (url.scheme() == QLatin1StringView("mailto")) {
         return KEmailAddress::decodeMailtoUrl(url);
     }
     return {};
@@ -53,7 +53,7 @@ QString MailToURLHandlerWebEngine::statusBarMessage(const QUrl &url, ArticleView
 
 bool MailToURLHandlerWebEngine::handleContextMenuRequest(const QUrl &url, const QPoint &p, ArticleViewerWebEngine *) const
 {
-    if (url.scheme() == QLatin1String("mailto")) {
+    if (url.scheme() == QLatin1StringView("mailto")) {
         auto menu = new QMenu();
         QAction *copy = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("&Copy Email Address"));
 
@@ -76,7 +76,7 @@ bool MailToURLHandlerWebEngine::handleContextMenuRequest(const QUrl &url, const
 
 bool MailToURLHandlerWebEngine::handleClick(const QUrl &url, ArticleViewerWebEngine *) const
 {
-    if (url.scheme() == QLatin1String("mailto")) {
+    if (url.scheme() == QLatin1StringView("mailto")) {
         QDesktopServices::openUrl(url);
         return true;
     }
@@ -85,28 +85,28 @@ bool MailToURLHandlerWebEngine::handleClick(const QUrl &url, ArticleViewerWebEng
 
 bool ActionURLHandlerWebEngine::handleContextMenuRequest(const QUrl &url, const QPoint &, ArticleViewerWebEngine *) const
 {
-    return url.scheme() == QLatin1String("akregatoraction");
+    return url.scheme() == QLatin1StringView("akregatoraction");
 }
 
 QString ActionURLHandlerWebEngine::statusBarMessage(const QUrl &url, ArticleViewerWebEngine *) const
 {
-    if (url.scheme() == QLatin1String("akregatoraction")) {
+    if (url.scheme() == QLatin1StringView("akregatoraction")) {
         const QString urlPath(url.path());
-        if (urlPath == QLatin1String("delete")) {
+        if (urlPath == QLatin1StringView("delete")) {
             return i18n("Delete Article");
-        } else if (urlPath == QLatin1String("markAsRead")) {
+        } else if (urlPath == QLatin1StringView("markAsRead")) {
             return i18n("Mark Article as Read");
-        } else if (urlPath == QLatin1String("markAsUnRead")) {
+        } else if (urlPath == QLatin1StringView("markAsUnRead")) {
             return i18n("Mark Article as Unread");
-        } else if (urlPath == QLatin1String("markAsImportant")) {
+        } else if (urlPath == QLatin1StringView("markAsImportant")) {
             return i18n("Change Important Flag");
-        } else if (urlPath == QLatin1String("sendUrlArticle")) {
+        } else if (urlPath == QLatin1StringView("sendUrlArticle")) {
             return i18n("Send the URL of the article");
-        } else if (urlPath == QLatin1String("sendFileArticle")) {
+        } else if (urlPath == QLatin1StringView("sendFileArticle")) {
             return i18n("Send the Html Page of Article");
-        } else if (urlPath == QLatin1String("openInExternalBrowser")) {
+        } else if (urlPath == QLatin1StringView("openInExternalBrowser")) {
             return i18n("Open In External Browser");
-        } else if (urlPath == QLatin1String("openInBackgroundTab")) {
+        } else if (urlPath == QLatin1StringView("openInBackgroundTab")) {
             return i18n("Open In Background Tab");
         }
         return {};
@@ -116,35 +116,35 @@ QString ActionURLHandlerWebEngine::statusBarMessage(const QUrl &url, ArticleView
 
 bool ActionURLHandlerWebEngine::handleClick(const QUrl &url, ArticleViewerWebEngine *articleViewer) const
 {
-    if (url.scheme() == QLatin1String("akregatoraction")) {
+    if (url.scheme() == QLatin1StringView("akregatoraction")) {
         const QString urlPath(url.path());
         if (url.hasQuery()) {
             const QUrlQuery urlQuery(url);
             const QString articleId = urlQuery.queryItemValue(QStringLiteral("id"));
             const QString feed = urlQuery.queryItemValue(QStringLiteral("feed"));
             if (!articleId.isEmpty()) {
-                if (urlPath == QLatin1String("delete")) {
+                if (urlPath == QLatin1StringView("delete")) {
                     articleViewer->setArticleAction(ArticleViewerWebEngine::DeleteAction, articleId, feed);
                     return true;
-                } else if (urlPath == QLatin1String("markAsRead")) {
+                } else if (urlPath == QLatin1StringView("markAsRead")) {
                     articleViewer->setArticleAction(ArticleViewerWebEngine::MarkAsRead, articleId, feed);
                     return true;
-                } else if (urlPath == QLatin1String("markAsUnRead")) {
+                } else if (urlPath == QLatin1StringView("markAsUnRead")) {
                     articleViewer->setArticleAction(ArticleViewerWebEngine::MarkAsUnRead, articleId, feed);
                     return true;
-                } else if (urlPath == QLatin1String("markAsImportant")) {
+                } else if (urlPath == QLatin1StringView("markAsImportant")) {
                     articleViewer->setArticleAction(ArticleViewerWebEngine::MarkAsImportant, articleId, feed);
                     return true;
-                } else if (urlPath == QLatin1String("sendUrlArticle")) {
+                } else if (urlPath == QLatin1StringView("sendUrlArticle")) {
                     articleViewer->setArticleAction(ArticleViewerWebEngine::SendUrlArticle, articleId, feed);
                     return true;
-                } else if (urlPath == QLatin1String("sendFileArticle")) {
+                } else if (urlPath == QLatin1StringView("sendFileArticle")) {
                     articleViewer->setArticleAction(ArticleViewerWebEngine::SendFileArticle, articleId, feed);
                     return true;
-                } else if (urlPath == QLatin1String("openInExternalBrowser")) {
+                } else if (urlPath == QLatin1StringView("openInExternalBrowser")) {
                     articleViewer->setArticleAction(ArticleViewerWebEngine::OpenInExternalBrowser, articleId, feed);
                     return true;
-                } else if (urlPath == QLatin1String("openInBackgroundTab")) {
+                } else if (urlPath == QLatin1StringView("openInBackgroundTab")) {
                     articleViewer->setArticleAction(ArticleViewerWebEngine::OpenInBackgroundTab, articleId, feed);
                     return true;
                 }
